@@ -11,9 +11,9 @@ from typing import TYPE_CHECKING
 
 import pytest
 from griffe import Docstring, DocstringSectionExamples, DocstringSectionKind, Module, temporary_visited_module
+from mkdocstrings import CollectionError
 
-from mkdocstrings_handlers.python.config import PythonConfig, PythonOptions
-from mkdocstrings_handlers.python.handler import CollectionError, PythonHandler
+from mkdocstrings_handlers.python import PythonConfig, PythonHandler, PythonOptions
 
 if TYPE_CHECKING:
     from mkdocstrings import MkdocstringsPlugin
@@ -160,9 +160,6 @@ def test_rendering_object_source_without_lineno(handler: PythonHandler) -> None:
         """,
     )
     with temporary_visited_module(code) as module:
-        # TODO: Remove once Griffe does that automatically.
-        module.lines_collection[module.filepath] = code.splitlines()  # type: ignore[index]
-
         module["Class"].lineno = None
         module["Class.function"].lineno = None
         module["attribute"].lineno = None
